@@ -1,6 +1,5 @@
-import os
 import sys
-import subprocess
+from datetime import datetime, timedelta
 from textwrap import dedent
 
 from dsframework.base.batch.dag_base import ZIDS_Dag
@@ -9,6 +8,7 @@ from dsframework.base.batch.dag_base import ZIDS_Dag
 class Dag(ZIDS_Dag):
     def __init__(self):
         """! Loads config file and initializes parameters.
+        Please make sure to determine the start date according to your project needs.
         """
 
         # dag params from airflow 1 - https://airflow.apache.org/docs/apache-airflow/1.10.3/macros.html
@@ -20,6 +20,9 @@ class Dag(ZIDS_Dag):
         else:
             self.file_name = self.project_name + "_dag.py"
 
+        # This setting will give the dag an execution date of the day before its creation.
+        self.dag_start_delay = 1
+
     def create_dag(self):
         """! Dag creation.
         This function creates the python file which contains the DAG itself.
